@@ -24,7 +24,8 @@ struct Game {
 
 impl PartialEq for Game {
     fn eq(&self, other: &Game) -> bool {
-        self.hole_idx == other.hole_idx && self.weight == other.weight
+        self.hole_idx == other.hole_idx
+            && self.weight == other.weight
             && self.positions == other.positions
     }
 }
@@ -51,9 +52,7 @@ lazy_static! {
                 2 if idx % SIDE < SIDE - 1 => Some(idx + 1),
                 3 if idx < SIDE * SIDE - SIDE => Some(idx + SIDE),
                 _ => None,
-            })
-            .collect::<Vec<_>>())
-        .collect();
+            }).collect::<Vec<_>>()).collect();
 }
 
 impl Game {
